Introduction — Pynauty

# Introduction

pynauty is a Python/C extension module. It can be used to compare graphs for isomorphism and to determine their automorphism group in a Python programming environment.

pynauty is using library components from the Nauty package by Brendan McKay.

Current version: 1.1.2

pynauty is compatible with Python 3.7-3.9 and nauty27r1.

## Licence

Copyright (c) 2015-2021 Peter Dobsan

pynauty is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see http://www.gnu.org/licenses/.

Please note, Nauty’s source code is not distributed with this package, you need to download it separately. Nauty is covered by its own licencing terms. For details, see Nauty’s web-site.